#include "ijk.h"

/* Put in oricutron.cfg:
   ---------------------
   ; Joystick interface for Atmos/Oric-1 mode. Telestrat has its own built-in standard.
   ; Options are 'none', 'altai', 'pase' or 'ijk'
   joyinterface = ijk

   ; How to emulate joysticks attached to the above interface
   ; Options are 'none', 'kbjoy1', 'kbjoy2', 'sdljoyN' (where n is 0 to 9)
   joystick_a = kbjoy1
   joystick_b = kbjoy2

   ; How to emulate joysticks attached to the telestrat
   ; Options are 'none', 'kbjoy1', 'kbjoy2', 'sdljoyN', 'mouse'
   telejoy_a = kbjoy1
   telejoy_b = kbjoy2

   ; Keys to emulate joystick, set 1
   ; NOTE: "fire2" is only available on telestrat
   kbjoy1_up = 'W'
   kbjoy1_down = 'S'
   kbjoy1_left = 'A'
   kbjoy1_right = 'D'
   kbjoy1_fire1 = 'Z'
   kbjoy2_fire2 = 'X'

   ; Keys to emulate joystick, set 2
   kbjoy2_up = 'I'
   kbjoy2_down = 'K'
   kbjoy2_left = 'J'
   kbjoy2_right = 'L'
   kbjoy2_fire1 = 'M'
   kbjoy2_fire2 = ','
   ---------------------
*/

#define CURSOR      0x01  /* Cursor on             (ctrl-q) */
#define SCREEN      0x02  /* Printout to screen on (ctrl-s) */
#define NOKEYCLICK  0x08  /* Turn keyclick off     (ctrl-f) */
#define PROTECT     0x20  /* Protect columns 0-1   (ctrl-]) */
#define getflags()  peek(0x26a)
#define setflags(x) poke(0x26a,x)

static unsigned char flags;

int main(void)
{
  // cls
  printf("%c", 12);

  flags = getflags();
  setflags(NOKEYCLICK|SCREEN);

  // screen row/col
  doke(0x12, 0xbb80+40*1);
  poke(0x268, 1);
  poke(0x269, 2);
  printf("Press: ESC to quit\n\n");
  printf("------------------\n");
  printf(" In Oricutron use:\n\n");
  printf("------------------\n");
  printf("   JOY-1  JOY-2   \n");
  printf("     W      I     \n");
  printf("    A D    J L    \n");
  printf("     S      K     \n");
  printf("     Z      M     \n");
  printf("------------------\n");

  // clear key pressed
  poke(0x2df,0);

  // ESC to quit
  while(0x9b != peek(0x2df))
  {
    // screen row/col
    doke(0x12, 0xbb80+40*14);
    poke(0x268, 14);
    poke(0x269, 2);

    ijk_detect();
    printf("    IJK %s\n", ijk_present==0 ? "absent":"present");
    printf("------------------\n");

    if(ijk_present)
    {
      ijk_read();

      printf("     %c      %c    \n", ijk_joy_1&0x10? '^':' ', ijk_joy_2&0x10? '^':' ');
      printf("   %c   %c  %c   %c  \n",  ijk_joy_1&0x01? '<':' ', ijk_joy_1&0x02? '>':' ',  ijk_joy_2&0x01? '<':' ', ijk_joy_2&0x02? '>':' ');
      printf("     %c      %c    \n\n", ijk_joy_1&0x08? 'v':' ', ijk_joy_2&0x08? 'v':' ');
      printf("    |%c|    |%c|   \n", ijk_joy_1&0x20? 'X':' ', ijk_joy_2&0x20? 'X':' ');
    }

  }

  // cls
  printf("%c", 12);
  setflags(flags);

  return 0;
}
